<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-forum?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// F
	'forum_description' => 'Foru de SPIP (priváu y públicu)',
	'forum_slogan' => 'Alministración de foros privaos y públicos en SPIP',
];
